"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getToolbarsConfigs = exports.createConfig = void 0;
const constants_1 = require("../../modules/toolbars/constants");
const presets_1 = require("../../modules/toolbars/presets");
const toolbar_1 = require("../../toolbar");
const defaultPresets = {
    zero: presets_1.zero,
    commonmark: presets_1.commonmark,
    default: presets_1.defaultPreset,
    yfm: presets_1.yfm,
    full: presets_1.full,
};
const transformItem = (type, item, id = 'unknown') => {
    var _a;
    if (!item) {
        console.warn(`Toolbar item "${id}" not found, it might not have been added to the items dictionary.`);
        return {};
    }
    const isListButton = item.view.type === toolbar_1.ToolbarDataType.ListButton;
    return Object.assign(Object.assign(Object.assign({ type: (_a = item.view.type) !== null && _a !== void 0 ? _a : toolbar_1.ToolbarDataType.SingleButton, id, title: item.view.title, hint: item.view.hint, icon: item.view.icon, hotkey: item.view.hotkey }, (isListButton && { withArrow: item.view.withArrow })), (type === 'wysiwyg' && item.wysiwyg && Object.assign({}, item.wysiwyg))), (type === 'markup' && item.markup && Object.assign({}, item.markup)));
};
const createConfig = (editorType, toolbarPreset, toolbarName) => {
    var _a;
    const preset = typeof toolbarPreset === 'string'
        ? defaultPresets[toolbarPreset] || defaultPresets.default
        : toolbarPreset;
    const orders = (_a = preset.orders[toolbarName]) !== null && _a !== void 0 ? _a : [[]];
    const { items } = preset;
    const toolbarData = orders.map((group) => group.map((action) => {
        return typeof action === 'string'
            ? transformItem(editorType, items[action], action)
            : Object.assign(Object.assign({}, transformItem(editorType, items[action.id], action.id)), { data: action.items.map((id) => transformItem(editorType, items[id], id)) });
    }));
    return toolbarData;
};
exports.createConfig = createConfig;
const flattenPreset = (config) => {
    var _a;
    // TODO: @makhnatkin add logic for flatten
    return ((_a = config[0]) !== null && _a !== void 0 ? _a : []);
};
const getToolbarsConfigs = ({ toolbarsPreset, props, preset }) => {
    var _a, _b, _c, _d;
    const wysiwygToolbarConfig = toolbarsPreset
        ? (0, exports.createConfig)('wysiwyg', toolbarsPreset, constants_1.ToolbarName.wysiwygMain)
        : (_a = props.wysiwygToolbarConfig) !== null && _a !== void 0 ? _a : (0, exports.createConfig)('wysiwyg', preset, constants_1.ToolbarName.wysiwygMain);
    const markupToolbarConfig = toolbarsPreset
        ? (0, exports.createConfig)('markup', toolbarsPreset, constants_1.ToolbarName.markupMain)
        : (_b = props.markupToolbarConfig) !== null && _b !== void 0 ? _b : (0, exports.createConfig)('markup', preset, constants_1.ToolbarName.markupMain);
    const wysiwygHiddenActionsConfig = toolbarsPreset
        ? flattenPreset((0, exports.createConfig)('wysiwyg', toolbarsPreset, constants_1.ToolbarName.wysiwygHidden))
        : (_c = props.wysiwygHiddenActionsConfig) !== null && _c !== void 0 ? _c : flattenPreset((0, exports.createConfig)('wysiwyg', preset, constants_1.ToolbarName.wysiwygHidden));
    const markupHiddenActionsConfig = toolbarsPreset
        ? flattenPreset((0, exports.createConfig)('markup', toolbarsPreset, constants_1.ToolbarName.markupHidden))
        : (_d = props.markupHiddenActionsConfig) !== null && _d !== void 0 ? _d : flattenPreset((0, exports.createConfig)('markup', preset, constants_1.ToolbarName.markupHidden));
    return {
        wysiwygToolbarConfig,
        markupToolbarConfig,
        wysiwygHiddenActionsConfig,
        markupHiddenActionsConfig,
    };
};
exports.getToolbarsConfigs = getToolbarsConfigs;
